# To access FPGA device continuously

puts "Loading deconft tool"
load deconft.dll


puts "Loading FPGA access command\n"
puts "##########################"
puts "cmd usage: fa <loop count>"
puts "##########################\n"

puts "-- fa command will access FPGA register 0x404 'loop count' times"
puts "-- Only 2 LS bits will be used to access with specific pattern (0,1,2,3,0...)"
puts "-- Message will be thrown only if read-write access fails or compare fails"

# FPGA access procedure
proc fa {arg2} {

	# Opening the device
	set res [bcdevopen]
	set rc [lindex $res 0]
	if {$rc != 0} {
		error "Error opening the device"
	}
	
	# Read-Write Access test
	for {set i 0} {$i < $arg2} {incr i} {

		# Writing incremental data to 0x404
		set wval [expr $i & 0x3]
		set res [bcwrfpga 404 $wval]
		set rc [lindex $res 0]
		if {$rc == 0} {

			# Reading the data from 0x404
			set res [bcrdfpga 404]
#			puts $res
			set rc [lindex $res 0]
			if {$rc == 0} {

				# Comparing the read and written data
				set val [lindex [lindex $res 1] 2]
				set rval [expr int($val) & 0x3]
				if {$rval == $wval} {			
#					puts "RD/WR Compare Passed: WrVal = $wval, RdVal = $rval"
				} else {
					puts "RD/WR Compare Failed: WrVal = $wval, RdVal = $rval"
				}
			} else {
				puts "FPGA Register Read FAILED!"
			}

		} else {
			puts "FPGA Register Write FAILED!"
		}

	}

	# Closing the device
	set res [bcdevclose]
	set rc [lindex $res 0]
	if {$rc != 0} {
		error "Error closing the device"
	}
}